#!/bin/bash
Summary: Utilities for monitoring process activities.
Name: psacct
Version: 6.3.2
Release: 10.21as
License: GPL
Group: Applications/System
Source: ftp://ftp.gnu.org/pub/gnu/acct-6.3.2.tar.gz
Patch0: acct-6.3.2-config.patch
Patch1: acct-6.3.2-exit.patch
Patch2: psacct-6.3.2-64bit-fixes.patch
Patch3: psacct-6.3.2-hz.patch
Buildroot: %{_tmppath}/%{name}-%{version}-root
Prereq: /sbin/install-info
BuildRequires: autoconf

%description
The psacct package contains several utilities for monitoring process
activities, including ac, lastcomm, accton and sa. The ac command
displays statistics about how long users have been logged on. The
lastcomm command displays information about previous executed
commands. The accton command turns process accounting on or off. The
sa command summarizes information about previously executed
commmands.

%prep
%setup -q -n acct-%{version}
%patch0 -p0 -b .config
%patch1 -p1
%patch2 -p1 -b .64bit
%patch3 -p1 -b .hz

%build
autoconf
%configure
sed -e "s/\/\* #undef HAVE_LINUX_ACCT_H \*\//#define HAVE_LINUX_ACCT_H/" config.h > config.h.new
mv -f config.h.new config.h
touch texinfo.tex
make

%install
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT{/sbin,%{_bindir},%{_mandir},%{_sbindir},%{_var}/log}
%{makeinstall}

# move accton to /sbin -- leave historical symlink
mv $RPM_BUILD_ROOT%{_sbindir}/accton $RPM_BUILD_ROOT/sbin/accton
ln -s ../../sbin/accton $RPM_BUILD_ROOT%{_sbindir}/accton

gzip -9f $RPM_BUILD_ROOT%{_infodir}/*
touch $RPM_BUILD_ROOT%{_var}/log/pacct
touch $RPM_BUILD_ROOT%{_var}/log/usracct
touch $RPM_BUILD_ROOT%{_var}/log/savacct

mkdir -p $RPM_BUILD_ROOT/etc/logrotate.d
cat > $RPM_BUILD_ROOT/etc/logrotate.d/psacct <<EOF
# Logrotate file for psacct RPM
 
/var/log/pacct {
prerotate
        %{_sbindir}/accton
endscript
	compress
	notifempty
        daily
	rotate 31
postrotate
        %{_sbindir}/accton %{_var}/log/pacct
endscript
}     
EOF


%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%post
# we need this hack to get rid of an old, incorrect accounting info entry.
if [ $1 = 0 ]; then
  grep -v '* accounting: (psacct)' < /etc/info-dir > /etc/info-dir.new
  mv -f /etc/info-dir.new /etc/info-dir
  /sbin/install-info %{_infodir}/accounting.info.gz %{_infodir}/dir --entry="* accounting: (accounting).            The GNU Process Accounting Suite."
fi

%preun
if [ $1 = 0 ]; then
   /sbin/install-info --delete %{_infodir}/accounting.info.gz %{_infodir}/dir --entry="* accounting: (accounting).            The GNU Process Accounting Suite." 2>/dev/null
fi

%files
%defattr(-,root,root)
%attr(0600,root,root)	%config /var/log/pacct
%attr(0600,root,root)	%config /var/log/usracct
%attr(0600,root,root)	%config /var/log/savacct
%attr(0644,root,root)	%config(noreplace) /etc/logrotate.d/*
/sbin/accton
%{_sbindir}/accton
%{_sbindir}/sa
%{_sbindir}/dump-utmp
%{_sbindir}/dump-acct
%{_bindir}/ac
%{_bindir}/lastcomm
%{_mandir}/man1/ac.1*
%{_mandir}/man1/lastcomm.1*
%{_mandir}/man8/sa.8*
%{_mandir}/man8/accton.8*
%{_infodir}/accounting.info.gz

%changelog
* Mon Jun 21 2004 Jay Fenlason <fenlason@redhat.com> 6.3.2-10.21as
- Merged patches for #117813 and #117817

* Thu Sep 06 2001 Mike A. Harris <mharris@redhat.com> 6.3.2-9
- Fixed bug (#53307) psacct is enabled by default, and the log files
  are huge, and will fill the disk up very quickly.  logrotate will
  now compress them daily.

* Sat Sep 01 2001 Florian La Roche <Florian.LaRoche@redhat.de> 6.3.2-8
- do not fail for ENOSYS to silently support kernels without
  process accounting

* Sun Aug 26 2001 Mike A. Harris <mharris@redhat.com> 6.3.2-7
- Change spec tag Copyright -> License
- change logrotate to rotate daily, and keep 1 month (31 days) of data

* Sun Jun 24 2001 Elliot Lee <sopwith@redhat.com>
- Bump release + rebuild.

* Mon Feb 02 2001 Helge Deller <hdeller@redhat.de>
- added logrotate file for /var/log/pacct (#24900)

* Wed Jul 12 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Mon Jun  5 2000 Nalin Dahyabhai <nalin@redhat.com>
- FHS fixes

* Sat May  6 2000 Bill Nottingham <notting@redhat.com>
- fix for new patch

* Thu Feb 03 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to 6.3.2

* Mon Apr 05 1999 Preston Brown <pbrown@redhat.com>
- wrap post script with reference count.

* Tue Mar 23 1999 Preston Brown <pbrown@redhat.com>
- install-info sucks.  Still.

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 8)

* Thu Mar 18 1999 Bill Nottingham <notting@redhat.com>
- #define HAVE_LINUX_ACCT_H too, so it works. :)

* Sun Aug 16 1998 Jeff Johnson <jbj@redhat.com>
- accton needs to be accessible to /etc/rc.d/init.d/halt

* Fri May 08 1998 Erik Troan <ewt@redhat.com>
- install-info sucks

* Mon Apr 27 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Thu Oct 23 1997 Donnie Barnes <djb@redhat.com>
- updated from 6.2 to 6.3

* Mon Jul 21 1997 Erik Troan <ewt@redhat.com>
- built against glibc
